@@ -13,6 +13,9 @@
 
    I am NOT a C programmer and this code likely proves that, but this code works
    and that's good enough for me.
+
+   Also note, portions of this code (which I initially wrote) have been
+   optimized by GitHub AI for both speed and reduction of complexity.
 */
 
 #include <fcntl.h>
@@ -840,7 +843,7 @@ void c_plot(char *framebuffer,
             *((uint16_t *)p) = res16;
         } break;
 
-        case 8: {
+        case 8: { /* Not supported yet, but here is the code if it ever is */
             uint8_t fb = *p;
             uint8_t col8 = (uint8_t)color;
             uint8_t res8 = fb;
@@ -1263,8 +1266,8 @@ void c_blit_write(char *framebuffer,
                   short yy_clip) {
     short fb_x = xoffset + x;
     short fb_y = yoffset + y;
-    short xx = x + w;
-    short yy = y + h;
+    short xx = x + w - 1;
+    short yy = y + h - 1;
     unsigned int bline = (unsigned int)w * (unsigned int)bytes_per_pixel;
 
     /* Fastest is unclipped normal mode (keep original memcpy path) */
